## cdist-type__update_alternatives(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__update_alternatives - Configure alternatives

## 2. DESCRIPTION

On Debian and alike systems update-alternatives(1) can be used to setup alternatives for various programs. One of the most common used targets is the "editor".

## 3. REQUIRED PARAMETERS

path
  Use this path for the given alternative

## 4. EXAMPLES

    # Setup vim as the default editor
    __update_alternatives editor --path /usr/bin/vim.basic

## 5. SEE ALSO

- cdist-type(7)
- cdist-type__debconf_set_selections(7)
- update-alternatives(8)

## 6. COPYING

Copyright (C) 2013 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).